// -*- C++ -*-
#include "tao/New_Leader_Generator.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_New_Leader_Generator::~TAO_New_Leader_Generator ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
